/// <reference types="knockout" />
import { Style, StyleObservable } from "../style/style";
import { Attribute } from "./attribute";
import { IEventListener, IAddEventListenerOptions } from "./eventListener";
import * as types from "../types/types";
export interface UiElementOptions {
    id?: string;
    elementType?: string;
    visible?: boolean | KnockoutObservable<boolean>;
    className?: string | KnockoutObservable<string>;
    attributes?: Array<Attribute>;
    eventListeners?: Array<IEventListener>;
    style?: StyleObservable;
    selectable?: boolean;
    addControlToDataDictionary?: boolean;
}
export declare abstract class UiElement {
    protected constructor(tagName: string, elementType: string, options?: UiElementOptions);
    private display;
    private setVisibility;
    private knockoutSubscriptions;
    protected element: HTMLElement;
    protected readonly options: UiElementOptions;
    protected build(): void;
    protected addSubscription(observable: KnockoutObservable<any>, callback: (newValue: any) => void): void;
    render(): HTMLElement;
    refresh(): void;
    remove(): void;
    getElement(): HTMLElement;
    getAttribute(attributeName: types.AttributeName): string | number;
    setAttribute(name: types.AttributeName, value: string | number | KnockoutObservable<string | number>): void;
    deleteAttribute(attributeName: string): void;
    getStyle(...cssProperties: Array<types.CssProperty>): Style;
    setStyle(newStyle: Style, overwriteExisting?: boolean): void;
    deleteStyle(style: types.CssProperty | Array<types.CssProperty> | Style): void;
    addEventListener<TType extends keyof HTMLElementEventMap>(type: TType, listener: (this: HTMLElement, event: HTMLElementEventMap[TType], uiElement: UiElement) => any, options?: boolean | IAddEventListenerOptions): void;
    readonly tagName: string;
    readonly visible: boolean;
    readonly attributes: {
        [index: string]: string | number | KnockoutObservable<string | number>;
    };
}
